{

NTSC character based TV Text driver, with HUB RAM font table   Rev. 02.1

This is just a demo stub to get things running.  See TV driver for more info.  Run this to
see how to incorporate the driver into your own project.

What differentiates this driver from other tile drivers is how the screen memory is done.  Instead
of the screen containing colors and addresses, only character definition numbers are stored.
(in the two color per screen mode)  This makes writing numbers, strings, etc... to the screen a
simple matter of moving the string bytes to the display memory, without having to do address
lookups.

In the colors per char mode, the same idea applies, but it's all about longs instead of bytes.  

The parameters needed to get the driver running are here.  Essentially, you need to define
a segment of RAM for the screen display memory (.5 - 4Kb), display colors, and supply the font table
pointer address to the TV driver.  Other, display specific parameters are in the driver constants,
detailed there.

This quick and dirty demo program will just display the font on screen, using either the 2 color per
screen or 2 color per character modes.  Uncomment the color per character mode, to explore color options.

Once the driver is up and running, all other COGs can be stopped, leaving it to display whatever
character definition numbers are in the screen memory.  

Doug Dingus  10/07

}

CON
  ' Set up the processor clock in the standard way for 80MHz on HYDRA
  ' You will want to edit this to reflect your clock setup
  ' Also necessary is editing the pin definitions, and that's done in the driver itself.
  _CLKMODE = xtal2 + pll8x
  _XINFREQ = 10_000_000 + 0000
  'crlf = $0a0d
  CR  = $0D
  LF  = $0A
  TAB = $09
  BKS = $08

  
VAR
  byte          displayb[4096]   'allocate max display buffer in RAM  40x24 (longs)

  long          index            'just an index...

  long          params[5]                                    'The address of this array gets 
                '[0] screen memory                            passed to the TV driver.
                '[1] font table
                '[2] pix_mode not yet implemented...
                '[3] colors, or 16 bit mode = $00
  long ptr
  byte row
  byte col

            
    
OBJ
  tv : "char_mode_10_TV"         'the actual TV display driver
  'fsrw : "fsrwFemto"
PUB start(dspPins) |  c, o, d, p
    
    params[0] := @displayb
{
    Simple display buffer, one character per byte.  40x24 = 960 bytes, unless color per
    character mode is on.  In that case, it's one long per character displayed on screen.
}
    ptr := @fonttab
    if byte[ ptr+constant(" "*8) ] 
      byte[ ptr+constant(" "*8) ] := 0
    repeat constant(128 * 8)
     byte[ ptr++ ] := byte[ ptr ] >< 8
     
    params[1] := @fonttab
{
    Address of font table.  Each char is 8x8.  There are 128 of these defined in
    this display driver.  User can add or subtract from this as memory and
    display requirements demand.  Driver tested for 256 chars.

    Feel free to create your own font tables.  This one is from an old Atari computer.
    Any 8x8 font should work just fine.  Be sure to mirror the pixels.  This is necessary to
    address how the waitvid command works.

    %1100_0000  --->   %000_0011 = XX------  Where "X" is set on-screen pixel "-" is a reset one.
    
}
    
    params[2] := $0000_0000    'Not implemented....  
  
    
    'params[3] := $00_00_07_FB    
    params[3] := $00           'Uncomment this to set color per char "fat" mode.
                                'fat being a reference to the increase in screen memory
                                'required to handle color per char mode.


    params[4]:= dspPins

    tv.start(@params)    'start the tv cog & pass it the parameter block
    ClearScreen

PUB ClearScreen
    repeat index from 0 to 4095 step 4
      displayb[index] := 2
      displayb[index+1] := 7
      displayb[index+2] := 0
      displayb[index+3] := 32
    row := 0
    col := 0

PUB PrintStrAt(x,y,fg,bg,char,RevFlag) | c,i,t,nf,nb
    col:=x
    row:=y

    if RevFlag == 1
      t := fg
      fg := bg
      bg := t  
     
    repeat i from 0 to strSize(char) - 1
      if byte[char][i] == 249
        nf :=1
        next
      if nf == 1
        nf := 0
        fg := byte[char][i]
        next          

      if byte[char][i] == 255
        nb :=1
        next
      if nb == 1
        nb := 0
        bg := byte[char][i]
        next          

      if byte[char][i] == 13
        row++
        next
      if byte[char][i] == 10
        col:=0
        next

      if byte[char][i] == 0
        abort     
      displayb[col*4 + row*160] := bg 'Colors[bg]
      displayb[col*4+ 1 + row*160] := fg 'Colors[fg]
      displayb[col*4+ 3 + row*160] := byte[char][i] '^ 32
      col++

PUB CharAt(x,y) | i
    i:= displayb[x*4+ 3 + y*160]
    return i   

PUB SwapColors(x,y) | t
    t:=displayb[x*4 + y*160] 
    displayb[x*4 + y*160]:= displayb[x*4+ 1 + y*160]
    displayb[x*4+ 1 + y*160] := t
    
    
{
PUB Print(char)
    repeat i from 0 to strSize(char) - 1
      displayb[col*4 + y*160] := bg
      displayb[col*4+ 1 + y*160] := fg
      displayb[col*4+ 3 + y*160] := byte[char][i]
      col++
}
DAT

fonttab byte byte %00001000     ' ....#...    $00
        byte byte %00011100     ' ...###..
        byte byte %00111110     ' ..#####.
        byte byte %01111111     ' .#######
        byte byte %01111111     ' .#######
        byte byte %00011100     ' ...###..
        byte byte %00111110     ' ..#####.
        byte byte %00000000     ' ........

        byte byte %00011000     ' ...##...    $01
        byte byte %00011000     ' ...##..
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...

        byte byte %00000000     ' ........    $02
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %11111111     ' ########
        byte byte %11111111     ' ########
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $03
        byte byte %00000000     ' ........
        byte byte %11111111     ' ########
        byte byte %11111111     ' ########
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %11111111     ' ........    $04
        byte byte %11111111     ' ########
        byte byte %00000000     ' ########
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     '.........

        byte byte %00000000     ' ........    $05
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %11111111     ' ########
        byte byte %11111111     ' ########

        byte byte %00110000     ' ..##....    $06
        byte byte %00110000     ' ..##....
        byte byte %00110000     ' ..##....
        byte byte %00110000     ' ..##....
        byte byte %00110000     ' ..##....
        byte byte %00110000     ' ..##....
        byte byte %00110000     ' ..##....
        byte byte %00110000     ' ..##....

        byte byte %00001100     ' ....##..    $07
        byte byte %00001100     ' ....##..
        byte byte %00001100     ' ....##..
        byte byte %00001100     ' ....##..
        byte byte %00001100     ' ....##..
        byte byte %00001100     ' ....##..
        byte byte %00001100     ' ....##..
        byte byte %00001100     ' ....##..

        byte byte %00000011     ' ........    $08
        byte byte %00000011     ' ........
        byte byte %00000011     ' ........
        byte byte %00000011     ' ###.....
        byte byte %00000011     ' ####....
        byte byte %00000011     ' ..###...
        byte byte %11111111     ' ...##...
        byte byte %11111111     ' ...##...

        byte byte %00011000     ' ...##...    $09
        byte byte %00011000     ' ...##...
        byte byte %00011100     ' ...###..
        byte byte %00001111     ' ....####
        byte byte %00000111     ' .....###
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %00011000     ' ...##...    $0A
        byte byte %00011000     ' ...##...
        byte byte %00111000     ' ..###...
        byte byte %11110000     ' ####....
        byte byte %11100000     ' ###.....
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %11000000     ' ##......    $0B
        byte byte %11000000     ' ##......
        byte byte %11000000     ' ##......
        byte byte %11000000     ' ##......
        byte byte %11000000     ' ##......
        byte byte %11000000     ' ##......
        byte byte %11111111     ' ########
        byte byte %11111111     ' ########

        byte byte %11000000     ' ##......    $0C
        byte byte %11100000     ' ###.....
        byte byte %01110000     ' .###....
        byte byte %00111000     ' ..###...
        byte byte %00011100     ' ...###..
        byte byte %00001110     ' ....###.
        byte byte %00000111     ' .....###
        byte byte %00000011     '.......##

        byte byte %00000011     ' ......##    $0D
        byte byte %00000111     ' .....###
        byte byte %00001110     ' ....###.
        byte byte %00011100     ' ...###..
        byte byte %00111000     ' ..###...
        byte byte %01110000     ' .###....
        byte byte %11100000     ' ###.....
        byte byte %11000000     ' ##......

        byte byte %11111111     ' ########    $0E
        byte byte %11111111     ' ########
        byte byte %11000000     ' ##......
        byte byte %11000000     ' ##......
        byte byte %11000000     ' ##......
        byte byte %11000000     ' ##......
        byte byte %11000000     ' ##......
        byte byte %11000000     ' ##......

        byte byte %11111111     ' ########    $0F
        byte byte %11111111     ' ########
        byte byte %00000011     ' ......##
        byte byte %00000011     ' ......##
        byte byte %00000011     ' ......##
        byte byte %00000011     ' ......##
        byte byte %00000011     ' ......##
        byte byte %00000011     ' ......##
        
        byte byte %00000000     ' ........    $10
        byte byte %00111100     ' ..####..
        byte byte %01111110     ' .######.
        byte byte %01111110     ' .######.
        byte byte %01111110     ' .######.
        byte byte %01111110     ' .######.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $11
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %11111111     ' ########
        byte byte %11111111     ' ########
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %00110110     ' ..##.##.    $12
        byte byte %01111111     ' .#######
        byte byte %01111111     ' .#######
        byte byte %01111111     ' .#######
        byte byte %00111110     ' ..#####.
        byte byte %00011100     ' ...###..
        byte byte %00001000     ' ....#...
        byte byte %00000000     ' ........

        byte byte %11000000     ' .##.....    $13
        byte byte %11000000     ' .##.....
        byte byte %11000000     ' .##.....
        byte byte %11000000     ' .##.....
        byte byte %11000000     ' .##.....
        byte byte %11000000     ' .##.....
        byte byte %11000000     ' .##.....
        byte byte %11000000     ' .##.....

        byte byte %00000000     ' ........    $14
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000111     ' .....###          
        byte byte %00001111     ' ....####
        byte byte %00011100     ' ...###..
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...


        byte byte %11000011     ' ##....##    $15
        byte byte %11100111     ' ###..###
        byte byte %01111110     ' .######.
        byte byte %00111100     ' ..####..
        byte byte %00111100     ' ..####..
        byte byte %01111110     ' .######.
        byte byte %11100111     ' ###..###
        byte byte %11000011     ' ##....##

        byte byte %00000000     ' ........    $16
        byte byte %00111100     ' ..####..
        byte byte %01111110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01111110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00011000     ' ...##...    $17
        byte byte %00011000     ' ...##...
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##..
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00000011     ' .....##.    $18
        byte byte %00000011     ' .....##.
        byte byte %00000011     ' .....##.
        byte byte %00000011     ' .....##.
        byte byte %00000011     ' .....##.
        byte byte %00000011     ' .....##.
        byte byte %00000011     ' .....##.
        byte byte %00000011     ' .....##.

        byte byte %00001000     ' ....#...    $19
        byte byte %00011100     ' ...###..
        byte byte %00111110     ' ..#####.
        byte byte %01111111     ' .#######
        byte byte %00111110     ' ..#####.
        byte byte %00011100     ' ...###..
        byte byte %00001000     ' ....#...
        byte byte %00000000     ' ........

        byte byte %00011000     ' ...##...    $1A
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %11111111     ' ########
        byte byte %11111111     ' ########
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...


        byte byte %11000000     ' ##.....    $1B
        byte byte %11000000     ' ##.....
        byte byte %00110000     ' ..##...
        byte byte %00110000     ' ..##...
        byte byte %11000000     ' ##.....
        byte byte %11000000     ' ##.....
        byte byte %00110000     ' ..##...
        byte byte %00110000     ' ..##...

        byte byte %00011000     ' ...##...    $1C
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...

        byte byte %00000000     ' ........    $1D
        byte byte %00000000     ' ........
        byte byte %00000011     ' ......##
        byte byte %00111110     ' ..#####.
        byte byte %01110110     ' .###.##.
        byte byte %00110110     ' ..##.##.
        byte byte %00110110     ' ..##.##.
        byte byte %00000000     ' ........

        byte byte %11111111     ' ########    $1E
        byte byte %01111111     ' .#######
        byte byte %00111111     ' ..######
        byte byte %00011111     ' ...#####
        byte byte %00001111     ' ....####
        byte byte %00000111     ' .....###
        byte byte %00000011     ' ......##
        byte byte %00000001     ' .......#

        byte byte %11110000     ' ####....    $1F
        byte byte %11110000     ' ####....
        byte byte %11110000     ' ####....
        byte byte %11110000     ' ####....
        byte byte %11110000     ' ####....
        byte byte %11110000     ' ####....
        byte byte %11110000     ' ####....
        byte byte %11110000     ' ####....


        byte byte %00000000     ' ........    $20  Space
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %00011000     ' ...##...    $21  !
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........

        byte byte %01100110     ' .##..##.    $22  "
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %01100110     ' .##..##.    $23  #
        byte byte %01100110     ' .##..##.
        byte byte %11111111     ' ########
        byte byte %01100110     ' .##..##.
        byte byte %11111111     ' ########
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00000000     ' ........

        byte byte %00011000     ' ...##...    $24  $
        byte byte %00111110     ' ..#####.
        byte byte %01100000     ' .##.....
        byte byte %00111100     ' ..####..
        byte byte %00000110     ' .....##.
        byte byte %01111100     ' .#####..
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........

        byte byte %01100010     ' .##...#.    $25  %
        byte byte %01100110     ' .##..##.
        byte byte %00001100     ' ....##..
        byte byte %00011000     ' ...##...
        byte byte %00110000     ' ..##....
        byte byte %01100110     ' .##..##.
        byte byte %01000110     ' .#...##.
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $26  &
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00111000     ' ..###...
        byte byte %01100111     ' .##..###
        byte byte %01100110     ' .##..##.
        byte byte %00111111     ' ..######
        byte byte %00000000     ' ........

        byte byte %00000110     ' .....##.    $27  '
        byte byte %00001100     ' ..,.##..
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %00001100     ' ....##..    $28  (
        byte byte %00011000     ' ...##...
        byte byte %00110000     ' ..##....
        byte byte %00110000     ' ..##....
        byte byte %00110000     ' ..##....
        byte byte %00011000     ' ...##...
        byte byte %00001100     ' ....##..
        byte byte %00000000     ' ........

        byte byte %01100000     ' ..##....    $29  )
        byte byte %00110000     ' ...##...
        byte byte %00011000     ' ....##..
        byte byte %00001100     ' ....##..
        byte byte %00001100     ' ....##..
        byte byte %00011000     ' ...##...
        byte byte %00110000     ' ..##....
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $2A  *
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %11111111     ' ########
        byte byte %00111100     ' ..####..
        byte byte %01100110     ' .##..##.
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $2B  +
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %01111110     ' .######.
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $2C  ,
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00110000     ' ..##....

        byte byte %00000000     ' ........    $2D  -
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %01111110     ' .######.
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $2E  .
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $2F  /
        byte byte %00000110     ' .....##.
        byte byte %00001100     ' ....##..
        byte byte %00011000     ' ...##...
        byte byte %00110000     ' ..##....
        byte byte %01100000     ' .##.....
        byte byte %01000000     ' .#......
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $30  0
        byte byte %01100110     ' .##..##
        byte byte %01101110     ' .##.###.
        byte byte %01110110     ' .###.##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00011000     ' ...##...    $31  1
        byte byte %00011000     ' ...##...
        byte byte %00111000     ' ..###...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %01111110     ' .######.
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $32  2
        byte byte %01100110    ' ..##..##.
        byte byte %00000110     ' .....##.
        byte byte %00011000     ' ...##...
        byte byte %00110000     ' ..##....
        byte byte %01100000     ' .##.....
        byte byte %01111110     ' .######.
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $33  3
        byte byte %01100110     ' .##..##.
        byte byte %00000110     ' .....##.
        byte byte %00011100     ' ...###..
        byte byte %00000110     ' .....##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00000110     ' .....##.    $34  4
        byte byte %00001110     ' ....###.
        byte byte %00011110     ' ...####.
        byte byte %01100110     ' .##..##.
        byte byte %01111111     ' .#######
        byte byte %00000110     ' .....##.
        byte byte %00000110     ' .....##.
        byte byte %00000000     ' ........

        byte byte %01111110     ' .######.    $35  5
        byte byte %01100000     ' .##.....
        byte byte %01111100     ' .#####..
        byte byte %00000110     ' .....##.
        byte byte %00000110     ' .....##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $36  6
        byte byte %01100110     ' .##..##.
        byte byte %01100000     ' .##.....
        byte byte %01111100     ' .#####..
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %01111110     ' .######.    $37  7
        byte byte %01100110     ' .##..##.
        byte byte %00001100     ' ....##..
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $38  8
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $39  9
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111110     ' ..#####.
        byte byte %00000110     ' .....##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $3A  :
        byte byte %00000000     ' ........
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $3B  ;
        byte byte %00000000     ' ........
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00110000     ' ..##....

        byte byte %00001110     ' ....###.    $3C  <
        byte byte %00011000     ' ...##...
        byte byte %00110000     ' ..##....
        byte byte %01100000     ' .##.....
        byte byte %00110000     ' ..##....
        byte byte %00011000     ' ...##...
        byte byte %00001110     ' ....###.
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $3D  =
        byte byte %00000000     ' ........
        byte byte %01111110     ' .######.
        byte byte %00000000     ' ........
        byte byte %01111110     ' .######.
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %01110000     ' .###....    $3E  >
        byte byte %00011000     ' ...##...
        byte byte %00001100     ' ....##..
        byte byte %00000110     ' .....##.
        byte byte %00001100     ' ....##..
        byte byte %00011000     ' ...##...
        byte byte %01110000     ' .###....
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $3F  ?
        byte byte %01100110     ' .##..##.
        byte byte %00000110     ' .....##.
        byte byte %00001100     ' ....##..
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $40  @
        byte byte %00111100     ' ..####..
        byte byte %01100110     ' .##..##.
        byte byte %01101110     ' .##.###.
        byte byte %01101110     ' .##.###.
        byte byte %01100000     ' .##.....
        byte byte %00111110     ' ..#####.
        byte byte %00000000     ' ........

        byte byte %00011000     ' ...##...    $41  A
        byte byte %00111100     ' ..####..
        byte byte %00100100     ' .##..##.
        byte byte %01111110     ' .######.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00000000     ' ........

        byte byte %01111100     ' .#####..    $42  B
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01111100     ' .#####..
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01111100     ' .#####..
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $43  C
        byte byte %01100110     ' .##..##.
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %01111000     ' .####...    $44  D
        byte byte %01101100     ' .##.##...
        byte byte %01100110     ' .##..##..
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01101100     ' .##.##..
        byte byte %01111000     ' .####...
        byte byte %00000000     ' ........

        byte byte %01111110     ' .######.    $45  E
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01111100     ' .#####..
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01111110     ' .######.
        byte byte %00000000     ' ........

        byte byte %01111110     ' .######.    $46  F
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01111100     ' .#####..
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $47  G
        byte byte %01100110     ' .##..##.
        byte byte %01100000     ' .##.....
        byte byte %01101110     ' .##.###.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %01100110     ' .##..##.    $48  H
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01111110     ' .######.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $49  I
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00011110     ' ...####.    $4A  J
        byte byte %00001100     ' ....##..
        byte byte %00001100     ' ....##..
        byte byte %00001100     ' ....##..
        byte byte %00001100     ' ....##..
        byte byte %01101100     ' .##.##..
        byte byte %00111000     ' ..###...
        byte byte %00000000     ' ........

        byte byte %01100110     ' .##..##.    $4B  K
        byte byte %01101100     ' .##.##..
        byte byte %01111000     ' .####...
        byte byte %01110000     ' .###....
        byte byte %01111000     ' .####...
        byte byte %01101100     ' .##.##..
        byte byte %01100110     ' .##..##.
        byte byte %00000000     ' ........

        byte byte %01100000     ' .##.....    $4C  L
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01111110     ' .######.
        byte byte %00000000     ' ........

        byte byte %01100011     ' .##...##    $4D  M
        byte byte %01110111     ' .###.###
        byte byte %01111111     ' .#######
        byte byte %01101011     ' .##.#.##
        byte byte %01101011     ' .##...##
        byte byte %01100011     ' .##...##
        byte byte %01100011     ' .##...##
        byte byte %00000000     ' ........

        byte byte %01100110     ' .##..##.    $4E  N
        byte byte %01110110     ' .###.##.
        byte byte %01111110     ' .######.
        byte byte %01111110     ' .######.
        byte byte %01101110     ' .##.###.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $4F  O
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %01111100     ' .#####..    $50  P
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01111100     ' .#####..
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $51  Q
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00001110     ' ....###.
        byte byte %00000000     ' ........

        byte byte %01111100     ' .#####..    $52  R
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01111100     ' .#####..
        byte byte %01111000     ' .####...
        byte byte %01101100     ' .##.##..
        byte byte %01100110     ' .##..##.
        byte byte %00000000     ' ........

        byte byte %00111100     ' ..####..    $53  S
        byte byte %01100110     ' .##..##.
        byte byte %01100000     ' .##.....
        byte byte %00111100     ' ..####..
        byte byte %00000110     ' .....##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %01111110     ' .######.    $54  T
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........

        byte byte %01100110     ' .##..##.    $55  U
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %01100110     ' .##..##.    $56  V
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........

        byte byte %01100011     ' .##...##    $57  W
        byte byte %01100011     ' .##...##
        byte byte %01100011     ' .##...##
        byte byte %01101011     ' .##.#.##
        byte byte %01111111     ' .#######
        byte byte %01110111     ' .###.###
        byte byte %01100011     ' .##...##
        byte byte %00000000     ' ........

        byte byte %01100110     ' .##..##.    $58  X
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00011000     ' ...##...
        byte byte %00111100     ' ..####..
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00000000     ' ........

        byte byte %01100110     ' .##..##.    $59  Y
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........

        byte byte %01111110     ' .######.    $5A  Z
        byte byte %00000110     ' .....##.
        byte byte %00001100     ' ....##..
        byte byte %00011000     ' ...##...
        byte byte %00110000     ' ..##....
        byte byte %01100000     ' .##.....
        byte byte %01111110     ' .######.
        byte byte %00000000     ' ........

        byte byte %00011110     ' ...####.    $5B  [
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011110     ' ...####.
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $5C  \
        byte byte %01000000     ' .#......
        byte byte %01100000     ' .##.....
        byte byte %00110000     ' ..##....
        byte byte %00011000     ' ...##...
        byte byte %00001100     ' ....##..
        byte byte %00000110     ' .....##.
        byte byte %00000000     ' ........

        byte byte %01111000     ' .####...    $5D  ]
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %01111000     ' .####...
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $5E  ^
        byte byte %00001000     ' ....#...
        byte byte %00011100     ' ...###..
        byte byte %00110110     ' ..##.##.
        byte byte %01100011     ' .##...##
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $5F  _
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %01111110     ' .######.
        byte byte %00000000     ' ........

        byte byte %00011000     ' ...##...    $60  `
        byte byte %00000000     ' ........
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $61  a
        byte byte %00000000     ' ........
        byte byte %00111100     ' ..####..
        byte byte %00000110     ' .....##.
        byte byte %00111110     ' ..#####.
        byte byte %01100110     ' .##..##.
        byte byte %00111110     ' ..#####.
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $62  b
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01111100     ' .#####..
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01111100     ' .#####..
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $63  c
        byte byte %00000000     ' ........
        byte byte %00111100     ' ..####..
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $64  d
        byte byte %00000110     ' .....##.
        byte byte %00000110     ' .....##.
        byte byte %00111110     ' ..#####.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111110     ' ..#####.
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $65  e
        byte byte %00000000     ' ........
        byte byte %00111100     ' ..####..
        byte byte %01100110     ' .##..##.
        byte byte %01111110     ' .######.
        byte byte %01100000     ' .##.....
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $66  f
        byte byte %00001110     ' ....###.
        byte byte %00011000     ' ...##...
        byte byte %00111110     ' ..#####.
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $67  g
        byte byte %00000000     ' ........
        byte byte %00111110     ' ..#####.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111110     ' ..#####.
        byte byte %00000110     ' .....##.
        byte byte %01111100     ' .#####..

        byte byte %00000000     ' ........    $68  h
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01111100     ' .#####..
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $69  i
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........
        byte byte %00111000     ' ..###...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $6A  j
        byte byte %00000110     ' .....##.
        byte byte %00000000     ' ........
        byte byte %00000110     ' .....##.
        byte byte %00000110     ' .....##.
        byte byte %00000110     ' .....##.
        byte byte %00000110     ' .....##.
        byte byte %00111100     ' ..####..

        byte byte %00000000     ' ........    $6B  k
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01101100     ' .##.##..
        byte byte %01111000     ' .####...
        byte byte %01101100     ' .##.##..
        byte byte %01100110     ' .##..##.
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $6C  l
        byte byte %00111000     ' ..###...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $6D  m
        byte byte %00000000     ' ........
        byte byte %01100110     ' .##..##.
        byte byte %01111111     ' .#######
        byte byte %01111111     ' .#######
        byte byte %01101011     ' .##.#.##
        byte byte %01100011     ' .##...##
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $6E  n
        byte byte %00000000     ' ........
        byte byte %01111100     ' .#####..
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $6F  o
        byte byte %00000000     ' ........
        byte byte %00111100     ' ..####..
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $70  p
        byte byte %00000000     ' ........
        byte byte %01111100     ' .#####..
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01111100     ' .#####..
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....

        byte byte %00000000     ' ........    $71  q
        byte byte %00000000     ' ........
        byte byte %00111110     ' ..#####.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111110     ' ..#####.
        byte byte %00000110     ' .....##.
        byte byte %00000110     ' .....##.

        byte byte %00000000     ' ........    $72  r
        byte byte %00000000     ' ........
        byte byte %01111100     ' .#####..
        byte byte %01100110     ' .##..##.
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %01100000     ' .##.....
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $73  s
        byte byte %00000000     ' ........
        byte byte %00111110     ' ..#####.
        byte byte %01100000     ' .##.....
        byte byte %00111100     ' ..####..
        byte byte %00000110     ' .....##.
        byte byte %01111100     ' .#####..
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $74  t
        byte byte %00011000     ' ...##...
        byte byte %01111110     ' .######.
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00001110     ' ....###.
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $75  u
        byte byte %00000000     ' ........
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111110     ' ..#####.
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $76  v
        byte byte %00000000     ' ........
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00011000     ' ...##...
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $77  w
        byte byte %00000000     ' ........
        byte byte %01100011     ' .##...##
        byte byte %01101011     ' .##.#.##
        byte byte %01111111     ' .#######
        byte byte %00111110     ' ..#####.
        byte byte %00110110     ' ..##.##.
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $78  x
        byte byte %00000000     ' ........
        byte byte %01100110     ' .##..##.
        byte byte %00111100     ' ..####..
        byte byte %00011000     ' ...##...
        byte byte %00111100     ' ..####..
        byte byte %01100110     ' .##..##.
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $79  y
        byte byte %00000000     ' ........
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %01100110     ' .##..##.
        byte byte %00111110     ' ..#####.
        byte byte %00001100     ' ....##..
        byte byte %01111000     ' .####...

        byte byte %00000000     ' ........    $7A  z
        byte byte %00000000     ' ........
        byte byte %01111110     ' .######.
        byte byte %00001100     ' ....##..
        byte byte %00011000     ' ...##...
        byte byte %00110000     ' ..##....
        byte byte %01111110     ' .######.
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $7B  {
        byte byte %00011100     ' ...###..
        byte byte %00011000     ' ...##...
        byte byte %01111000     ' .###....
        byte byte %01111000     ' .###....
        byte byte %00011000     ' ...##...
        byte byte %00011100     ' ...###..
        byte byte %00000000     ' ........

        byte byte %00011000     ' ...##...    $7C  |
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...
        byte byte %00011000     ' ...##...

        byte byte %00000000     ' ........    $7D  }
        byte byte %00111000     ' ..###...
        byte byte %00011000     ' ...##...
        byte byte %00011110     ' ....###.
        byte byte %00011110     ' ....###.
        byte byte %00011000     ' ...##...
        byte byte %00111000     ' ..###...
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $7E  ~
        byte byte %00110011     ' ..##..##
        byte byte %01111110     ' .######.
        byte byte %11001100     ' ##..##..
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........

        byte byte %00000000     ' ........    $7F
        byte byte %00111000     ' ..###...
        byte byte %01000100     ' .#...#..
        byte byte %01000100     ' .#...#..
        byte byte %00111000     ' ..###...
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........
        byte byte %00000000     ' ........


              'font definition pixels are mirror image, due to the way waitvid works.
              'Atari 8 bit international font used here
              'There are 128 chars defined in this table.  256 are possible.
{fonttab
           byte  %00000000   ' '       
           byte  %00000000             
           byte  %00000000             
           byte  %00000000             
           byte  %00000000             
           byte  %00000000             
           byte  %00000000             
           byte  %00000000             
                      
           byte  %00000000   '!'       
           byte  %00011000             
           byte  %00011000             
           byte  %00011000             
           byte  %00011000             
           byte  %00000000             
           byte  %00011000             
           byte  %00000000             
                      
           byte byte %00000000   '"'       
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
                       
           byte byte %00000000   '         
           byte byte %01100110             
           byte byte %11111111             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %11111111             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00011000   '$'       
           byte byte %01111100             
           byte byte %00000110             
           byte byte %00111100             
           byte byte %01100000             
           byte byte %00111110             
           byte byte %00011000             
           byte byte %00000000             
                       
           byte byte %00000000   '%'       
           byte byte %01100110             
           byte byte %00110110             
           byte byte %00011000             
           byte byte %00001100             
           byte byte %01100110             
           byte byte %01100010             
           byte byte %00000000             
                       
           byte byte %00111000   '&'       
           byte byte %01101100             
           byte byte %00111000             
           byte byte %00011100             
           byte byte %11110110             
           byte byte %01100110             
           byte byte %11011100             
           byte byte %00000000             
                       
           byte byte %00000000   '''       
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
                       
           byte byte %00000000   '('       
           byte byte %01110000             
           byte byte %00111000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00111000             
           byte byte %01110000             
           byte byte %00000000             
                      
           byte byte %00000000   ')'       
           byte byte %00001110             
           byte byte %00011100             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011100             
           byte byte %00001110             
           byte byte %00000000             
                       
           byte byte %00000000   '*'       
           byte byte %01100110             
           byte byte %00111100             
           byte byte %11111111             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %00000000             
           byte byte %00000000             
                       
           byte byte %00000000   '+'       
           byte byte %00011000             
           byte byte %00011000             
           byte byte %01111110             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00000000             
                       
           byte byte %00000000   ','       
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00001100             
                       
           byte byte %00000000   '-'       
           byte byte %00000000             
           byte byte %00000000             
           byte byte %01111110             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
                       
           byte byte %00000000   '.'       
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00000000             
                       
           byte byte %00000000   '/'       
           byte byte %01100000             
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00001100             
           byte byte %00000110             
           byte byte %00000010             
           byte byte %00000000             
                       
           byte byte %00000000   '0'       
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01110110             
           byte byte %01101110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   '1'       
           byte byte %00011000             
           byte byte %00011100             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %01111110             
           byte byte %00000000             
                       
           byte byte %00000000   '2'       
           byte byte %00111100             
           byte byte %01100110             
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00001100             
           byte byte %01111110             
           byte byte %00000000             
                       
           byte byte %00000000   '3'       
           byte byte %01111110             
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00110000             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   '4'       
           byte byte %00110000             
           byte byte %00111000             
           byte byte %00111100             
           byte byte %00110110             
           byte byte %01111110             
           byte byte %00110000             
           byte byte %00000000             
                       
           byte byte %00000000   '5'       
           byte byte %01111110             
           byte byte %00000110             
           byte byte %00111110             
           byte byte %01100000             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   '6'       
           byte byte %00111100             
           byte byte %00000110             
           byte byte %00111110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   '7'       
           byte byte %01111110             
           byte byte %01100000             
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00001100             
           byte byte %00001100             
           byte byte %00000000             
                       
           byte byte %00000000   '8'       
           byte byte %00111100             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   '9'       
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %01100000             
           byte byte %00110000             
           byte byte %00011100             
           byte byte %00000000             
                       
           byte byte %00000000   ':'       
           byte byte %00000000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00000000             
                       
           byte byte %00000000   '''       
           byte byte %00000000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00001100             
                       
           byte byte %01100000   '<'       
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00001100             
           byte byte %00011000             
           byte byte %00110000             
           byte byte %01100000             
           byte byte %00000000             
                       
           byte byte %00000000   '='       
           byte byte %00000000             
           byte byte %01111110             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %01111110             
           byte byte %00000000             
           byte byte %00000000             
                       
           byte byte %00000110   '>'       
           byte byte %00001100             
           byte byte %00011000             
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00001100             
           byte byte %00000110             
           byte byte %00000000             
                       
           byte byte %00000000   '?'       
           byte byte %00111100             
           byte byte %01100110             
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00011000             
           byte byte %00000000             
                       
           byte byte %00000000   '         
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01110110             
           byte byte %01110110             
           byte byte %00000110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %00000000   'A'       
           byte byte %00011000             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01111110             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00000000   'B'       
           byte byte %00111110             
           byte byte %01100110             
           byte byte %00111110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111110             
           byte byte %00000000             
                       
           byte byte %00000000   'C'       
           byte byte %00111100             
           byte byte %01100110             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   'D'       
           byte byte %00011110             
           byte byte %00110110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00110110             
           byte byte %00011110             
           byte byte %00000000             
                       
           byte byte %00000000   'E'       
           byte byte %01111110             
           byte byte %00000110             
           byte byte %00111110             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %01111110             
           byte byte %00000000             
                       
           byte byte %00000000   'F'       
           byte byte %01111110             
           byte byte %00000110             
           byte byte %00111110             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00000000             
                       
           byte byte %00000000   'G'       
           byte byte %01111100             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %01110110             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %00000000   'H'       
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01111110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00000000   'I'       
           byte byte %01111110             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %01111110             
           byte byte %00000000             
                       
           byte byte %00000000   'J'       
           byte byte %01100000             
           byte byte %01100000             
           byte byte %01100000             
           byte byte %01100000             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   'K'       
           byte byte %01100110             
           byte byte %00110110             
           byte byte %00011110             
           byte byte %00011110             
           byte byte %00110110             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00000000   'L'       
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %01111110             
           byte byte %00000000             
                       
           byte byte %00000000   'M'       
           byte byte %11000110             
           byte byte %11101110             
           byte byte %11111110             
           byte byte %11010110             
           byte byte %11000110             
           byte byte %11000110             
           byte byte %00000000             
                       
           byte byte %00000000   'N'       
           byte byte %01100110             
           byte byte %01101110             
           byte byte %01111110             
           byte byte %01111110             
           byte byte %01110110             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00000000   'O'       
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   'P'       
           byte byte %00111110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111110             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00000000             
                       
           byte byte %00000000   'Q'       
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00110110             
           byte byte %01101100             
           byte byte %00000000             
                       
           byte byte %00000000   'R'       
           byte byte %00111110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111110             
           byte byte %00110110             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00000000   'S'       
           byte byte %00111100             
           byte byte %00000110             
           byte byte %00111100             
           byte byte %01100000             
           byte byte %01100000             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   'T'       
           byte byte %01111110             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00000000             
                       
           byte byte %00000000   'U'       
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01111110             
           byte byte %00000000             
                       
           byte byte %00000000   'V'       
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00011000             
           byte byte %00000000             
                       
           byte byte %00000000   'W'       
           byte byte %11000110             
           byte byte %11000110             
           byte byte %11010110             
           byte byte %11111110             
           byte byte %11101110             
           byte byte %11000110             
           byte byte %00000000             
                       
           byte byte %00000000   'X'       
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00000000   'Y'       
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00000000             
                       
           byte byte %00000000   'Z'       
           byte byte %01111110             
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00001100             
           byte byte %00000110             
           byte byte %01111110             
           byte byte %00000000             
                       
           byte byte %00000000   '['       
           byte byte %01111000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %01111000             
           byte byte %00000000             
                       
           byte byte %00000000   '\'       
           byte byte %00000010             
           byte byte %00000110             
           byte byte %00001100             
           byte byte %00011000             
           byte byte %00110000             
           byte byte %01100000             
           byte byte %00000000             
                       
           byte byte %00000000   ']'       
           byte byte %00011110             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011110             
           byte byte %00000000             
                       
           byte byte %00000000   '^'       
           byte byte %00010000             
           byte byte %00111000             
           byte byte %01101100             
           byte byte %11000110             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
                       
           byte byte %00000000   '_'       
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00000000             
           byte byte %11111111             
           byte byte %00000000             
                       
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00111100             
           byte byte %01100000             
           byte byte %01111100             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %00001100             
           byte byte %00011000             
           byte byte %00000000             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %01101100             
           byte byte %00110110             
           byte byte %00000000             
           byte byte %01101110             
           byte byte %01101110             
           byte byte %01111110             
           byte byte %01110110             
           byte byte %00000000             
                       
           byte byte %00110000             
           byte byte %00011000             
           byte byte %01111110             
           byte byte %00000110             
           byte byte %00111110             
           byte byte %00000110             
           byte byte %01111110             
           byte byte %00000000             
                       
           byte byte %00000000             
           byte byte %00000000             
           byte byte %00111100             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00111100             
           byte byte %00011000             
           byte byte %00001100             
                       
           byte byte %00111100             
           byte byte %01100110             
           byte byte %00000000             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00001100             
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00001100             
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00011100             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00111000             
           byte byte %00001100             
           byte byte %00001100             
           byte byte %00011110             
           byte byte %00001100             
           byte byte %00001100             
           byte byte %01111110             
           byte byte %00000000             
                       
           byte byte %00000000             
           byte byte %01100110             
           byte byte %00000000             
           byte byte %00011100             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000             
           byte byte %01100110             
           byte byte %00000000             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %01101100             
           byte byte %00000000             
           byte byte %00111100             
           byte byte %01100000             
           byte byte %01111100             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %01100110             
           byte byte %00000000             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00000000             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000             
           byte byte %01100110             
           byte byte %00000000             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %01100110             
           byte byte %00000000             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01111110             
           byte byte %00000000             
                       
           byte byte %00111100             
           byte byte %01100110             
           byte byte %00111000             
           byte byte %01100000             
           byte byte %01111100             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %00111100             
           byte byte %01100110             
           byte byte %00000000             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %00111100             
           byte byte %01100110             
           byte byte %00000000             
           byte byte %00011100             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01111110             
           byte byte %00000110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00001100             
           byte byte %00011000             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01111110             
           byte byte %00000110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %01101100             
           byte byte %00110110             
           byte byte %00000000             
           byte byte %00111110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00111100             
           byte byte %11000011             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01111110             
           byte byte %00000110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00111100             
           byte byte %01100000             
           byte byte %01111100             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %00001100             
           byte byte %00011000             
           byte byte %00111100             
           byte byte %01100000             
           byte byte %01111100             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00011000             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01111110             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00011110             
           byte byte %00000110             
           byte byte %00011110             
           byte byte %00000110             
           byte byte %01111110             
           byte byte %00011000             
           byte byte %01111000             
           byte byte %00000000             
                       
           byte byte %00000000             
           byte byte %00011000             
           byte byte %00111100             
           byte byte %01111110             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00000000             
                       
           byte byte %00000000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %01111110             
           byte byte %00111100             
           byte byte %00011000             
           byte byte %00000000             
                       
           byte byte %00000000             
           byte byte %00011000             
           byte byte %00001100             
           byte byte %01111110             
           byte byte %00001100             
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00000000             
                       
           byte byte %00000000             
           byte byte %00011000             
           byte byte %00110000             
           byte byte %01111110             
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00000000             
                       
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00000000             
                       
           byte byte %00000000   'a'       
           byte byte %00000000             
           byte byte %00111100             
           byte byte %01100000             
           byte byte %01111100             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %00000000   'b'       
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00111110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111110             
           byte byte %00000000             
                       
           byte byte %00000000   'c'       
           byte byte %00000000             
           byte byte %00111100             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   'd'       
           byte byte %01100000             
           byte byte %01100000             
           byte byte %01111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %00000000   'e'       
           byte byte %00000000             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01111110             
           byte byte %00000110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   'f'       
           byte byte %01110000             
           byte byte %00011000             
           byte byte %01111100             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00000000             
                       
           byte byte %00000000   'g'       
           byte byte %00000000             
           byte byte %01111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %01100000             
           byte byte %00111110             
                       
           byte byte %00000000   'h'       
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00111110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00000000   'i'       
           byte byte %00011000             
           byte byte %00000000             
           byte byte %00011100             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   'j'       
           byte byte %01100000             
           byte byte %00000000             
           byte byte %01100000             
           byte byte %01100000             
           byte byte %01100000             
           byte byte %01100000             
           byte byte %00111100             
                       
           byte byte %00000000   'k'       
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00110110             
           byte byte %00011110             
           byte byte %00110110             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00000000   'l'       
           byte byte %00011100             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   'm'       
           byte byte %00000000             
           byte byte %01100110             
           byte byte %11111110             
           byte byte %11111110             
           byte byte %11010110             
           byte byte %11000110             
           byte byte %00000000             
                       
           byte byte %00000000   'n'       
           byte byte %00000000             
           byte byte %00111110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00000000   'o'       
           byte byte %00000000             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00000000             
                       
           byte byte %00000000   'p'       
           byte byte %00000000             
           byte byte %00111110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111110             
           byte byte %00000110             
           byte byte %00000110             
                       
           byte byte %00000000   'q'       
           byte byte %00000000             
           byte byte %01111100             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %01100000             
           byte byte %01100000             
                       
           byte byte %00000000   'r'       
           byte byte %00000000             
           byte byte %00111110             
           byte byte %01100110             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00000110             
           byte byte %00000000             
                       
           byte byte %00000000   's'       
           byte byte %00000000             
           byte byte %01111100             
           byte byte %00000110             
           byte byte %00111100             
           byte byte %01100000             
           byte byte %00111110             
           byte byte %00000000             
                       
           byte byte %00000000   't'       
           byte byte %00011000             
           byte byte %01111110             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %01110000             
           byte byte %00000000             
                       
           byte byte %00000000   'u'       
           byte byte %00000000             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00000000             
                       
           byte byte %00000000   'v'       
           byte byte %00000000             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00011000             
           byte byte %00000000             
                       
           byte byte %00000000   'w'       
           byte byte %00000000             
           byte byte %11000110             
           byte byte %11010110             
           byte byte %11111110             
           byte byte %01111100             
           byte byte %01101100             
           byte byte %00000000             
                       
           byte byte %00000000   'x'       
           byte byte %00000000             
           byte byte %01100110             
           byte byte %00111100             
           byte byte %00011000             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00000000   'y'       
           byte byte %00000000             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01100110             
           byte byte %01111100             
           byte byte %00110000             
           byte byte %00011110             
                       
           byte byte %00000000   'z'       
           byte byte %00000000             
           byte byte %01111110             
           byte byte %00110000             
           byte byte %00011000             
           byte byte %00001100             
           byte byte %01111110             
           byte byte %00000000             
                       
           byte byte %01100110             
           byte byte %01100110             
           byte byte %00011000             
           byte byte %00111100             
           byte byte %01100110             
           byte byte %01111110             
           byte byte %01100110             
           byte byte %00000000             
                       
           byte byte %00011000   '|'       
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
           byte byte %00011000             
                       
           byte byte %00000000             
           byte byte %01111110             
           byte byte %00011110             
           byte byte %00111110             
           byte byte %01110110             
           byte byte %01100110             
           byte byte %01100000             
           byte byte %00000000             
                       
           byte byte %00010000             
           byte byte %00011000             
           byte byte %00011100             
           byte byte %00011110             
           byte byte %00011100             
           byte byte %00011000             
           byte byte %00010000             
           byte byte %00000000             
                       
           byte byte %00001000             
           byte byte %00011000             
           byte byte %00111000             
           byte byte %01111000             
           byte byte %00111000             
           byte byte %00011000             
           byte byte %00001000             
           byte byte %00000000             
 }                                          
                                           
                                           
                                           
                                           
                                           
                                           
                                           
                                           
                                           
                                           
                                           
                                           
                                           
                                           
                                           