{

NTSC 8x8 Text driver.  Version 2.0   Doug Dingus 10/07

*Variable character sizes!  

  Two color per screen mode ranges from 10.0 to 70.0 chars per line.
        Screen size will increase.  Some compensation is possible, with overall_screen_size constant below.
        Above 64 chars, you will be using most of the NTSC video line no matter what.
        Number of chars above about 50, will see significant color artifacts.
                Use monochrome chars, with no hue, for best results.  

  Two color per character mode ranges from 10.0 to 40.0 chars per line.
        This waitvid loop is just a bit too long for anything higher.

  These ranges tested on 80Mhz HYDRA.  All bets are off at lower clocks, start small!  

*Variable number of character rows!

  All modes range 5 to 27 rows

*Vertical pixel size not yet implemented.

  When this happens, it will be number of scanlines per pixel.

ToDo's:

Move font into COG
Allow for both COG and HUB fonts
Multi-color mode  (4 color chars)
Vertical Size

}
CON
  ' Set up the processor clock in the standard way for 80MHz on a HYDRA
  ' Your setup may vary, so you will want to edit this!!
  _CLKMODE = xtal1 + pll8x
  _XINFREQ = 10_000_000 + 0000

PUB start(params) | i, j, k

  'We don't do much here, but launch the driver and point it to it's parameter block, defined by
  'the calling program.
  
  cognew(@entry,params)
  

DAT                     org
entry                   jmp     #initialization         'Jump past all the setup constants

'core video timing constants, palettes and such, should not need editing at all
CON  NTSC_color_frequency       =     3_579_545
DAT  NTSC_color_freq            long  NTSC_color_frequency
CON  NTSC_hsync_clocks          =               624
DAT  NTSC_hsync_VSCL              long  160368
DAT  NTSC_control_signal_palette long  $00_00_02_8a
DAT  NTSC_hsync_pixels          long  %%11_0000_1_2222222_11
CON  NTSC_active_video_clocks   =     3016
DAT  NTSC_active_video_VSCL     long  NTSC_active_video_clocks
CON  NTSC_lines_per_frame       =   244



'This area is stuff you edit for the pixel sizes, horizontal and vertical
'If this setup is for a bitmap driver, one can just key in pixel multiples of 8 and forget the char constant
CON number_of_chars_per_line = 40.0                           'needs to be a float
CON horizontal_pixels  =  number_of_chars_per_line * 8.0      'needs to be float and multiple of 8
CON number_of_character_rows = 25                             'number of lines of text total on screen
CON vertical_pixel_height = 1                                 'number of scan lines high (not active right now)

'Optional Edits below here

'Edit these to adjust the picture, their ranges depend on number of chars defined above
CON horizontal_offset    = 0                                  'place your picture along the x axis  + moves image right x # of clocks
CON vertical_offset      = 0                                  'place your picture along the y axis  + moves image down x # of scanlines
CON overall_image_size   = 200.0                              'Modify this to change picture width (about +-200 range)
'Both of these work in clocks, and depend on the clock speed of your prop, and number of chars defined above
'Start small, and work up until sync breaks to find limits.


'No edits required below here!!




'This section calculates the pixel clocks necessary, adjusting active video size as needed
CON INT_horizontal_pixels = TRUNC(horizontal_pixels)           '& %111_1111_1000 
CON clocks_per_active_scan_line = (ROUND((2360.0 + overall_image_size) / horizontal_pixels) * INT_horizontal_pixels)

CON clocks_per_pixel = clocks_per_active_scan_line / INT_horizontal_pixels

CON number_of_active_scan_lines = number_of_character_rows * 8

'Here the waitvids, for displayed pixels are setup (active user video area)
CON bytes_per_line = INT_horizontal_pixels / 8
CON waitvids_per_line = bytes_per_line
CON clocks_per_waitvid_frame   =  clocks_per_pixel*8
DAT CALC_user_data_VSCL         long  (clocks_per_pixel) << 12 +  clocks_per_waitvid_frame


'After all that is settled, we must define the horizontal overscan from what's left!
CON overscan = 3016 - clocks_per_active_scan_line               'that's the horizontal border total
CON color_correction = (overscan / 2) // clocks_per_pixel
CON backporch = (overscan / 2) + horizontal_offset + color_correction     'left side border
CON frontporch = (overscan - backporch)               'right side border

'And the vertical overscan too...

CON vert_overscan = 244 - number_of_active_scan_lines            'That's the vertical border total
CON vert_backporch = (vert_overscan / 2) + vertical_offset        'top border
CON vert_frontporch = (vert_overscan - vert_backporch)            'bottom border

DAT

'Setup the video generator hardware.  Using Cardboardguru's setup routine, unchanged from SIMPLE_NTSC.

initialization          'set up VCFG

                        ' VCFG: setup Video Configuration register and 3-bit tv DAC pins to output
                        movs    VCFG, #%0000_0111       ' VCFG'S = pinmask (pin31: 0000_0111 : pin24)
                        movd    VCFG, #3                ' VCFG'D = pingroup (grp. 3 i.e. pins 24-31)

                        movi    VCFG, #%0_10_111_000    ' baseband video on bottom nibble, 2-bit color, enable chroma on broadcast & baseband
                                                        ' %0_xx_x_x_x_xxx : Not used
                                                        ' %x_10_x_x_x_xxx : Composite video to top nibble, broadcast to bottom nibble
                                                        ' %x_xx_1_x_x_xxx : 4 color mode
                                                        ' %x_xx_x_1_x_xxx : Enable chroma on broadcast
                                                        ' %x_xx_x_x_1_xxx : Enable chroma on baseband
                                                        ' %x_xx_x_x_x_000 : Broadcast Aural FM bits (don't care)

                        or      DIRA, tvport_mask       ' set DAC pins to output

                        ' CTRA: setup Frequency to Drive Video
                        movi    CTRA,#%00001_111        ' pll internal routed to Video, PHSx+=FRQx (mode 1) + pll(16x)
                        mov     r1, NTSC_color_freq     ' r1: Color frequency in Hz (3.579_545MHz)
                        rdlong  v_clkfreq, #0           ' copy clk frequency. (80Mhz)
                        mov     r2, v_clkfreq           ' r2: CLKFREQ (80MHz)
                        call    #dividefract            ' perform r3 = 2^32 * r1 / r2
                        mov     v_freq, r3              ' v_freq now contains frqa.       (191)
                        mov     FRQA, r3                ' set frequency for counter


'get parameters from parameter block, and pass them to COG code here

                        mov     C, PAR                 ' get parameter block address
                        rdlong  A, C                   ' get screen address
                        mov     bmp, A                 ' store another copy
                        
                        add     C, #4                  'index to fonttab address
                        rdlong  fonttab, C             'store it 

                        add     C, #4                   'index to mode value
                        rdlong  pixel_mode, C           'store it 

                        add     C, #4                  'index to colors value
                        rdlong  colors, C              'store them...
                        mov     fat_mode, colors       'set color per char mode, if = $00000000        

'-----------------------------------------------------------------------------
                        'vertical overscan (26 blank lines, by default)
frame_loop                                                            
                        mov     line_loop, #vert_backporch          

:vert_back_porch        mov     VSCL, NTSC_hsync_VSCL
                        waitvid NTSC_control_signal_palette, hsync
                        
                        
                        mov     VSCL, NTSC_active_video_VSCL
                        waitvid top_overscan_color, #0      'draw blank line
                        djnz    line_loop, #:vert_back_porch
'-----------------------------------------------------------------------------

'-----------------------------------------------------------------------------
                        'This is the active display area, where graphics appear.

                        mov     line_loop, #number_of_active_scan_lines         'setup number of display lines
                        mov     fontline, #0                                    'set font scan offset to 0


                        
user_graphics_lines     mov     VSCL, NTSC_hsync_VSCL
                        waitvid NTSC_control_signal_palette, hsync    'hsync
                                                             
                        mov     VSCL,#backporch
                        waitvid left_overscan_color, #0                         'left overscan
                        
 
                        mov     VSCL, CALC_user_data_VSCL                       'set VSCL for 8 pixel blocks                         
                        movi    VCFG, #%0_10_011_000                            'two color mode
                        mov     r1, #waitvids_per_line                          'number of horiz pixels / 8

                        mov     fontsum, fonttab                                'pre add these to save instruction time
                        add     fontsum, fontline                               'in waitvid loop later on


                        tjz     fat_mode, #fat_bit_mode                         'color per char mode yes?   




:draw_pixels            rdbyte  B, A                    'get a character from screen memory (A)
                        shl     B, #3                    'multiply by 8, for char offset
                        add     B, fontsum               'add current scanline offset
                        rdbyte  C, B                    'read actual font pixels into (C)
                        add     A, #1                   'point to next set of chars
                        waitvid colors, C               'draw them to screen
                        djnz    r1, #:draw_pixels       'line done?
                        jmp    #end_active_video_line   'on to the right border
                        
                        'little endian design makes byte order different, adding some logic (rdlong)


fat_bit_mode            rdlong  B, A                 'get a character and colors from screen memory (A)
                        mov     colors, B            'set up colors
                        shr     B, #24          
                        shl     B, #3
                        add     B, fontsum
                        rdbyte  C, B
                        and     colors, color_mask
                        waitvid colors, C            'draw them to screen
                        add     A, #4                'point to next set of chars and colors
                        djnz    r1, #fat_bit_mode    'line done, if so, fall through to right border




                        
'===============================================================================================
  
end_active_video_line   mov    VSCL,#frontporch
                        waitvid right_overscan_color , border                   'overscan to the right...
                        movi    VCFG, #%0_10_111_000                            '4 color mode

                        tjz     fat_mode, #fat_offset                           'color per char (fat) mode yes?

                        'deal with scanline offset

                        add        fontline, #1
                        and        fontline, #%0111     wz
                if_nz   sub        A, #bytes_per_line    

                        jmp       #frame_draw

                                                                            
fat_offset              add        fontline, #1
                        and        fontline, #%0111  wz
                if_nz   sub        A, #bytes_per_line*4                        
                       

                        
                        
frame_draw             djnz    line_loop, #user_graphics_lines                  'done with visible screen?


                        
                        mov     A, bmp                                          'reset screen memory pointer for next frame
'-----------------------------------------------------------------------------
                        'Overscan at the bottom of screen.  
                        mov     line_loop, #vert_frontporch          
                        'hsync
vert_front_porch        mov     VSCL, NTSC_hsync_VSCL
                        waitvid NTSC_control_signal_palette, hsync
                        mov     VSCL, NTSC_active_video_VSCL
                        waitvid bottom_overscan_color, #0
                        djnz    line_loop, #vert_front_porch
'-----------------------------------------------------------------------------

                        mov     VSCL, NTSC_hsync_VSCL
                        waitvid bottom_overscan_color,NTSC_hsync_pixels
                        mov     vscl,NTSC_active_video_VSCL

                        mov     vscl,hrest
                        waitvid NTSC_control_signal_palette,vsync_high_2


                        'This is the vertical sync.  It consists of 3 sections of 6 lines each.
                        mov     line_loop, #6           '(250)
:vsync_higha            mov     VSCL, NTSC_hsync_VSCL
                        waitvid NTSC_control_signal_palette, vsync_high_1
                        mov     VSCL, NTSC_active_video_VSCL
                        waitvid NTSC_control_signal_palette, vsync_high_2
                        djnz    line_loop, #:vsync_higha
'-----------------------------------------------------------------------------
                        mov     line_loop, #6           '(256)
:vsync_low              mov     VSCL, NTSC_hsync_VSCL
                        waitvid NTSC_control_signal_palette, vsync_low_1
                        mov     VSCL, NTSC_active_video_VSCL
                        waitvid NTSC_control_signal_palette, vsync_low_2
                        djnz    line_loop, #:vsync_low
'-----------------------------------------------------------------------------
                        mov     line_loop, #6           '(250)
:vsync_highb            mov     VSCL, NTSC_hsync_VSCL
                        waitvid NTSC_control_signal_palette, vsync_high_1
                        mov     VSCL, NTSC_active_video_VSCL
                        waitvid NTSC_control_signal_palette, vsync_high_2
                        djnz    line_loop, #:vsync_highb
'-----------------------------------------------------------------------------

                        mov     vscl,hhalf              'if odd frame, do half line
                        waitvid NTSC_control_signal_palette, vsync_high_2
                        

                        jmp     #frame_loop

' General Purpose Registers
r0                      long                    $0     'should typically equal 0
r1                      long                    $0
r2                      long                    $0
r3                      long                    $0

A                       long                    $0     'coupla more general purpose registers
B                       long                    $0
C                       long                    $0  

bmp                     long                    $0     'tvpointer ends up here for use each frame 


pixel_mode              long                    $0  'unimplemented...


colors                  long                    $0000ddda                       'default, if not set by calling program
fontline                long                    $0                              'scanline counter
fonttab                 long                    $0                              'HUB memory address of font table
fat_mode                long                    $1                              'two color by default

fontsum                long                     $0                              'this is fontline + fonttab

color_mask              long                    $0000ffff
hrest                           long  1196
HHALF                           long  1820

' Video (TV) Registers
tvport_mask             long                    %0000_0111<<24
v_freq                  long                    0

' Graphics related vars.
v_clkfreq               long                    $0

' /////////////////////////////////////////////////////////////////////////////
' dividefract:
' Perform 2^32 * r1/r2, result stored in r3 (useful for TV calc)
' This is taken from the tv driver.
' NOTE: It divides a bottom heavy fraction e.g. 1/2 and gives the result as a 32-bit fraction.
' /////////////////////////////////////////////////////////////////////////////
dividefract                                     
                        mov     r0,#32+1
:loop                   cmpsub  r1,r2           wc
                        rcl     r3,#1
                        shl     r1,#1
                        djnz    r0,#:loop

dividefract_ret         ret                             '+140


'Pixel streams
'  These are shifted out of the VSU to the right, so lowest bits are actioned first.
'
hsync                   long    %%11_0000_1_2222222_11  ' Used with NTSC_control_signal_palette so:
                                                        '      0 = blanking level
                                                        '      1 = Black
                                                        '      2 = Color NTSC_control_signal_palette (yellow at zero value)
vsync_high_1            long    %%11111111111_222_11
vsync_high_2            long    %%1111111111111111
vsync_low_1             long    %%22222222222222_11
vsync_low_2             long    %%1_222222222222222
all_black               long    %%1111111111111111
border                  long    %%0000000000000000

' Some unimportant irrelevant constants for generating demo user display etc.
line_loop               long    0

'If you want, you can change the overscan border colors here.  

right_overscan_color    long    $03030303     'All set to grey
left_overscan_color     long    $03030303
bottom_overscan_color   long    $03030303
top_overscan_color      long    $03030303



                        